@@ -1,10 +1,18 @@
 //! `reqwest` based `pretend` client
+//!
+//! Feature `blocking` enables the blocking client.
 
 #![warn(missing_docs)]
 #![deny(unsafe_code)]
 
+#[cfg(feature = "blocking")]
+mod blocking;
+
 pub use reqwest;
 
+#[cfg(feature = "blocking")]
+pub use blocking::*;
+
 use pretend::client::{async_trait, Bytes, Client as PClient, Method};
 use pretend::{Error, HeaderMap, Response as PResponse, Result, Url};
 use reqwest::Client as RClient;
